@@ -32,6 +32,7 @@ class AnnotationType(enumerate):
     IMAGEANNOTATION = 6
     UNKNOWN = 255
 
+
 class ViewingProfile(object):
     blindMode = False
     annotator = None
@@ -52,6 +53,16 @@ class ViewingProfile(object):
     majorityClassVote = False
     activeClasses = dict()
 
+    def getColor(self, anno : "annotation"):
+        if (anno.pluginAnnotationLabel is not None):
+            return anno.pluginAnnotationLabel.color
+        if (self.blindMode):
+            return vp.COLORS_CLASSES[anno.labelBy(vp.annotator) ]
+        elif (self.majorityClassVote):
+            return self.COLORS_CLASSES[anno.majorityLabel() ]
+        else:
+            return self.COLORS_CLASSES[anno.agreedLabel()]
+
 
 """
   Annotation label class for plugins
@@ -203,7 +214,7 @@ class annotation():
           if (updateAgreed):
               self.agreedClass = self.majorityLabel()
 
-      def _create_annohandle(self, image:np.ndarray, coord:tuple, markersize:int, color:tuple, abscoord:tuple=(None,None)) -> AnnotationHandle:
+      def _create_annohandle(self, image:np.ndarray, coord:tuple, markersize:int, markersize_abs:float, color:tuple, abscoord:tuple=(None,None)) -> AnnotationHandle:
             pt1_rect = (max(0,coord[0]-markersize),
                         max(0,coord[1]-markersize))
             pt2_rect = (min(image.shape[1],coord[0]+markersize),
@@ -211,8 +222,8 @@ class annotation():
             cv2.rectangle(img=image, pt1=(pt1_rect), pt2=(pt2_rect), color=[255,255,255,255], thickness=2)
             cv2.rectangle(img=image, pt1=(pt1_rect), pt2=(pt2_rect), color=color, thickness=1)
 
-            pt1_abs = (abscoord[0]-markersize, abscoord[1]-markersize)
-            pt2_abs = (abscoord[0]+markersize, abscoord[1]+markersize)
+            pt1_abs = (abscoord[0]-markersize_abs, abscoord[1]-markersize_abs)
+            pt2_abs = (abscoord[0]+markersize_abs, abscoord[1]+markersize_abs)
             return AnnotationHandle(annoCoordinate(*pt1_rect, *pt1_abs), annoCoordinate(*pt2_rect, *pt2_abs))
 
       def getDimensions(self) -> (int, int):
@@ -279,15 +290,6 @@ class annotation():
                     return self.labels[label].classId
           return 0
         
-      def getColor(self, vp : ViewingProfile):
-          if (self.pluginAnnotationLabel is not None):
-              return self.pluginAnnotationLabel.color
-          if (vp.blindMode):
-            return vp.COLORS_CLASSES[self.labelBy(vp.annotator) ]
-          elif (vp.majorityClassVote):
-            return vp.COLORS_CLASSES[self.majorityLabel() ]
-          else:
-            return vp.COLORS_CLASSES[self.agreedLabel()]
       
       def minCoordinates(self) -> annoCoordinate:
             print('Whopsy... you need to overload this.')
@@ -308,10 +310,10 @@ class imageAnnotation(annotation):
     
       def draw(self, image: np.ndarray, leftUpper: tuple, zoomLevel: float, thickness: int, vp : ViewingProfile, selected = False):
 
-            image = cv2.rectangle(image, thickness=thickness, pt1=(0,0), pt2=(image.shape[1],image.shape[0]),color=self.getColor(vp), lineType=cv2.LINE_AA)
+            image = cv2.rectangle(image, thickness=thickness, pt1=(0,0), pt2=(image.shape[1],image.shape[0]),color=vp.getColor(self), lineType=cv2.LINE_AA)
 
             if (len(self.text)>0) and (zoomLevel < self.minimumAnnotationLabelZoom):
-                  cv2.putText(image, self.text, (10, 10), cv2.FONT_HERSHEY_PLAIN , 0.7,self.getColor(vp),1,cv2.LINE_AA)
+                  cv2.putText(image, self.text, (10, 10), cv2.FONT_HERSHEY_PLAIN , 0.7,vp.getColor(self),1,cv2.LINE_AA)
     
       def minCoordinates(self) -> annoCoordinate:
          return annoCoordinate(0,0)
@@ -360,13 +362,13 @@ class rectangularAnnotation(annotation):
       def convertToPath(self):
           return path.Path(np.array([[self.x1, self.x2, self.x2, self.x1, self.x1] ,[self.y1, self.y1, self.y2, self.y2, self.y1]]).T)
 
-      def draw(self, image: np.ndarray, leftUpper: tuple, zoomLevel: float, thickness: int, vp : ViewingProfile, selected = False):
+      def draw(self, image: np.ndarray, leftUpper: tuple, zoomLevel: float, thickness: int, vp : ViewingProfile = None, selected = False):
             xpos1=max(0,int((self.x1-leftUpper[0])/zoomLevel))
             ypos1=max(0,int((self.y1-leftUpper[1])/zoomLevel))
             xpos2=min(image.shape[1],int((self.x2-leftUpper[0])/zoomLevel))
             ypos2=min(image.shape[0],int((self.y2-leftUpper[1])/zoomLevel))
 
-            image = cv2.rectangle(image, thickness=thickness, pt1=(xpos1,ypos1), pt2=(xpos2,ypos2),color=self.getColor(vp), lineType=cv2.LINE_AA)
+            image = cv2.rectangle(image, thickness=thickness, pt1=(xpos1,ypos1), pt2=(xpos2,ypos2),color=vp.getColor(self), lineType=cv2.LINE_AA)
 
             if self.text is not None and (len(self.text)>0) and (zoomLevel < self.minimumAnnotationLabelZoom):
                   cv2.putText(image, self.text, (xpos1+3, ypos2+10), cv2.FONT_HERSHEY_PLAIN , 0.7,(0,0,0),1,cv2.LINE_AA)
@@ -451,18 +453,18 @@ class polygonAnnotation(annotation):
 
         for listIdx in range(self.coordinates.shape[0]-1):
             anno = slideToScreen(self.coordinates[listIdx])
-            cv2.line(img=image, pt1=anno, pt2=slideToScreen(self.coordinates[listIdx+1]), thickness=2, color=self.getColor(vp), lineType=cv2.LINE_AA)       
+            cv2.line(img=image, pt1=anno, pt2=slideToScreen(self.coordinates[listIdx+1]), thickness=2, color=vp.getColor(self), lineType=cv2.LINE_AA)       
 
             if (selected):
-                self.annoHandles.append(self._create_annohandle(image, anno, markersize, self.getColor(vp), abscoord=self.coordinates[listIdx]))
+                self.annoHandles.append(self._create_annohandle(image, anno, markersize, markersize*zoomLevel, vp.getColor(self), abscoord=self.coordinates[listIdx]))
 
 
         listIdx+=1
         anno = slideToScreen(self.coordinates[listIdx])
         if (selected):
-                self.annoHandles.append(self._create_annohandle(image, anno, markersize, self.getColor(vp), abscoord=self.coordinates[listIdx]))
+                self.annoHandles.append(self._create_annohandle(image, anno, markersize, markersize*zoomLevel,  vp.getColor(self), abscoord=self.coordinates[listIdx]))
 
-        cv2.line(img=image, pt1=anno, pt2=slideToScreen(self.coordinates[0]), thickness=2, color=self.getColor(vp), lineType=cv2.LINE_AA)       
+        cv2.line(img=image, pt1=anno, pt2=slideToScreen(self.coordinates[0]), thickness=2, color=vp.getColor(self), lineType=cv2.LINE_AA)       
 
         if (len(self.text)>0) and (zoomLevel < self.minimumAnnotationLabelZoom):
                 xpos1=int(0.5*(np.max(self.coordinates[:,0])+np.min(self.coordinates[:,0]) ))
@@ -519,7 +521,7 @@ class circleAnnotation(annotation):
             ypos1=int((self.y1-leftUpper[1])/zoomLevel)
             radius = int(self.r/zoomLevel)
             if (radius>=0):
-                  image = cv2.circle(image, thickness=thickness, center=(xpos1,ypos1), radius=radius,color=self.getColor(vp), lineType=cv2.LINE_AA)
+                  image = cv2.circle(image, thickness=thickness, center=(xpos1,ypos1), radius=radius,color=vp.getColor(self), lineType=cv2.LINE_AA)
             if (len(self.text)>0) and (zoomLevel < self.minimumAnnotationLabelZoom):
                     cv2.putText(image, self.text, (xpos1,ypos1), cv2.FONT_HERSHEY_PLAIN , 0.7,(0,0,0),1,cv2.LINE_AA)
 
@@ -555,7 +557,7 @@ class spotAnnotation(annotation):
             ypos1=int((self.y1-leftUpper[1])/zoomLevel)
             radius=int(int(vp.spotCircleRadius)/zoomLevel)
             if (radius>=0):
-                  image = cv2.circle(image, thickness=thickness, center=(xpos1,ypos1), radius=radius,color=self.getColor(vp), lineType=cv2.LINE_AA)
+                  image = cv2.circle(image, thickness=thickness, center=(xpos1,ypos1), radius=radius,color=vp.getColor(self), lineType=cv2.LINE_AA)
             if (len(self.text)>0) and (zoomLevel < self.minimumAnnotationLabelZoom):
                     cv2.putText(image, self.text, (xpos1+3, ypos1+10), cv2.FONT_HERSHEY_PLAIN , 0.7,(0,0,0),1,cv2.LINE_AA)
 
